def coach (files,n):
    try:
        if n > 0:
            with open (files[n-1]) as james:
                data = james.readline()
                james_line=data.strip().split(',')
            print (files[n-1]+': ')
            print(james_line)
            n=n-1
            coach (files,n)          
    except IOError as err:
        print ('Fehler:' +str(err))
    except ValueError as verr:
        print ('Fehler: ' +str(verr))



from distutils.core import setup
from setuptools import setup

setup(
    name       = 'ls_coach',
    version    = '1.0.1',
    py_modules = ['ls_coach'],
    author     = 'lecsim',
    author_email = 'lechler@gmx.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
)
